# UserRequest

A request to create a user.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**display_name** | **str** | An external identifier that can be used to match the buyer against your own records. This value needs to be unique for all buyers. | [optional] 
**email_address** | **str** | A unique name for this buyer which is used in the Gr4vy admin panel to give a buyer a human readable name. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


